@@ -19,7 +19,7 @@ use warnings;
 package MongoDB::_Credential;
 
 use version;
-our $VERSION = 'v1.6.1';
+our $VERSION = 'v1.8.0';
 
 use Moo;
 use MongoDB::Error;
@@ -126,7 +126,6 @@ my %CONSTRAINTS = (
         mechanism_properties => sub { !keys %$_ },
     },
     'MONGODB-X509' => {
-        username             => sub { length },
         password             => sub { ! length },
         source               => sub { $_ eq '$external' },
         mechanism_properties => sub { !keys %$_ },
@@ -218,10 +217,17 @@ sub _authenticate_MONGODB_CR {
 sub _authenticate_MONGODB_X509 {
     my ( $self, $link, $bson_codec ) = @_;
 
+    my $username = $self->username;
+
+    if ( !$username && !$link->accepts_wire_version(5) ) {
+        $username = $link->client_certificate_subject
+          or MongoDB::UsageError->throw("Could not extract subject from client SSL certificate");
+    }
+
     my $command = Tie::IxHash->new(
         authenticate => 1,
-        user         => $self->username,
         mechanism    => "MONGODB-X509",
+        ( $username ? ( user => $username ) : () ),
     );
     $self->_send_command( $link, $bson_codec, $self->source, $command );
 
@@ -339,7 +345,7 @@ sub _sasl_start {
     my $command = Tie::IxHash->new(
         saslStart     => 1,
         mechanism     => $mechanism,
-        payload       => $payload ? encode_base64( $payload, "" ) : "",
+        payload       => \$payload,
         autoAuthorize => 1,
     );
 
@@ -352,7 +358,7 @@ sub _sasl_continue {
     my $command = Tie::IxHash->new(
         saslContinue   => 1,
         conversationId => $conv_id,
-        payload        => $payload ? encode_base64( $payload, "" ) : "",
+        payload        => \$payload,
     );
 
     return $self->_sasl_send( $link, $bson_codec, $command );
@@ -362,7 +368,7 @@ sub _sasl_send {
     my ( $self, $link, $bson_codec, $command ) = @_;
     my $output = $self->_send_command( $link, $bson_codec, $self->source, $command )->output;
 
-    my $sasl_resp = $output->{payload} ? decode_base64( $output->{payload} ) : "";
+    my $sasl_resp = $output->{payload} ? $output->{payload}->data : "";
     return ( $sasl_resp, $output->{conversationId}, $output->{done} );
 }
 
