@@ -25,13 +25,13 @@ use warnings;
 package MongoDB::_Link;
 
 use version;
-our $VERSION = 'v1.6.1';
+our $VERSION = 'v1.8.0';
 
 use Moo;
 use Errno qw[EINTR EPIPE];
 use IO::Socket qw[SOCK_STREAM];
 use Scalar::Util qw/refaddr/;
-use Socket qw/SOL_SOCKET SO_KEEPALIVE SO_RCVBUF IPPROTO_TCP TCP_NODELAY/;
+use Socket qw/SOL_SOCKET SO_KEEPALIVE SO_RCVBUF IPPROTO_TCP TCP_NODELAY AF_INET/;
 use Time::HiRes qw/time/;
 use MongoDB::Error;
 use MongoDB::_Constants;
@@ -165,9 +165,16 @@ sub connect {
 
     my ($host, $port) = split /:/, $self->address;
 
+    # PERL-715: For 'localhost' where MongoDB is only listening on IPv4 and
+    # getaddrinfo returns an IPv6 address before an IPv4 address, some
+    # operating systems tickle a bug in IO::Socket::IP that causes
+    # connection attempts to fail before trying the IPv4 address.  As a
+    # workaround, we always force 'localhost' to use IPv4.
+
     my $fh = $SOCKET_CLASS->new(
         PeerHost => $host,
         PeerPort => $port,
+        ( lc($host) eq 'localhost' ? ( Family => AF_INET ) : () ),
         Proto    => 'tcp',
         Type     => SOCK_STREAM,
         Timeout  => $self->connect_timeout >= 0 ? $self->connect_timeout : undef,
@@ -259,6 +266,22 @@ sub start_ssl {
     }
 }
 
+sub client_certificate_subject {
+    my ($self) = @_;
+    return "" unless $self->fh && $self->fh->isa("IO::Socket::SSL");
+
+    my $client_cert = $self->fh->sock_certificate()
+      or return "";
+
+    my $subject_raw = Net::SSLeay::X509_get_subject_name($client_cert)
+      or return "";
+
+    my $subject =
+      Net::SSLeay::X509_NAME_print_ex( $subject_raw, Net::SSLeay::XN_FLAG_RFC2253() );
+
+    return $subject;
+}
+
 sub close {
     my ($self) = @_;
     $self->_close
